@@ -1,16 +1,12 @@
 use {
   super::*,
   clap::{
-    builder::{styling::AnsiColor, FalseyValueParser, PossibleValuesParser, Styles},
+    builder::{styling::AnsiColor, FalseyValueParser, Styles},
     parser::ValuesRef,
     value_parser, Arg, ArgAction, ArgGroup, ArgMatches, Command,
   },
 };
 
-const CHOOSE_HELP: &str = "Select one or more recipes to run using a binary chooser. \
-                           If `--chooser` is not passed the chooser defaults to the \
-                           value of $JUST_CHOOSER, falling back to `fzf`";
-
 #[derive(Debug, PartialEq)]
 pub(crate) struct Config {
   pub(crate) check: bool,
@@ -112,32 +108,6 @@ mod arg {
   pub(crate) const VERBOSE: &str = "VERBOSE";
   pub(crate) const WORKING_DIRECTORY: &str = "WORKING-DIRECTORY";
   pub(crate) const YES: &str = "YES";
-
-  pub(crate) const COLOR_ALWAYS: &str = "always";
-  pub(crate) const COLOR_AUTO: &str = "auto";
-  pub(crate) const COLOR_NEVER: &str = "never";
-  pub(crate) const COLOR_VALUES: &[&str] = &[COLOR_AUTO, COLOR_ALWAYS, COLOR_NEVER];
-
-  pub(crate) const COMMAND_COLOR_BLACK: &str = "black";
-  pub(crate) const COMMAND_COLOR_BLUE: &str = "blue";
-  pub(crate) const COMMAND_COLOR_CYAN: &str = "cyan";
-  pub(crate) const COMMAND_COLOR_GREEN: &str = "green";
-  pub(crate) const COMMAND_COLOR_PURPLE: &str = "purple";
-  pub(crate) const COMMAND_COLOR_RED: &str = "red";
-  pub(crate) const COMMAND_COLOR_YELLOW: &str = "yellow";
-  pub(crate) const COMMAND_COLOR_VALUES: &[&str] = &[
-    COMMAND_COLOR_BLACK,
-    COMMAND_COLOR_BLUE,
-    COMMAND_COLOR_CYAN,
-    COMMAND_COLOR_GREEN,
-    COMMAND_COLOR_PURPLE,
-    COMMAND_COLOR_RED,
-    COMMAND_COLOR_YELLOW,
-  ];
-
-  pub(crate) const DUMP_FORMAT_JSON: &str = "json";
-  pub(crate) const DUMP_FORMAT_JUST: &str = "just";
-  pub(crate) const DUMP_FORMAT_VALUES: &[&str] = &[DUMP_FORMAT_JUST, DUMP_FORMAT_JSON];
 }
 
 impl Config {
@@ -154,17 +124,20 @@ impl Config {
       .trailing_var_arg(true)
       .styles(
         Styles::styled()
-            .header(AnsiColor::Yellow.on_default())
-            .usage(AnsiColor::Yellow.on_default())
-            .literal(AnsiColor::Green.on_default())
-            .placeholder(AnsiColor::Green.on_default())
+          .header(AnsiColor::Yellow.on_default())
+          .literal(AnsiColor::Green.on_default())
+          .placeholder(AnsiColor::Green.on_default())
+          .usage(AnsiColor::Yellow.on_default()),
       )
       .arg(
         Arg::new(arg::CHECK)
           .long("check")
           .action(ArgAction::SetTrue)
           .requires(cmd::FORMAT)
-          .help("Run `--fmt` in 'check' mode. Exits with 0 if justfile is formatted correctly. Exits with 1 and prints a diff if formatting is required."),
+          .help(
+            "Run `--fmt` in 'check' mode. Exits with 0 if justfile is formatted correctly. \
+                 Exits with 1 and prints a diff if formatting is required.",
+          ),
       )
       .arg(
         Arg::new(arg::CHOOSER)
@@ -173,13 +146,20 @@ impl Config {
           .action(ArgAction::Set)
           .help("Override binary invoked by `--choose`"),
       )
+      .arg(
+        Arg::new(arg::CLEAR_SHELL_ARGS)
+          .long("clear-shell-args")
+          .action(ArgAction::SetTrue)
+          .overrides_with(arg::SHELL_ARG)
+          .help("Clear shell arguments"),
+      )
       .arg(
         Arg::new(arg::COLOR)
           .long("color")
           .env("JUST_COLOR")
           .action(ArgAction::Set)
-          .value_parser(PossibleValuesParser::new(arg::COLOR_VALUES))
-          .default_value(arg::COLOR_AUTO)
+          .value_parser(clap::value_parser!(UseColor))
+          .default_value("auto")
           .help("Print colorful output"),
       )
       .arg(
@@ -187,10 +167,24 @@ impl Config {
           .long("command-color")
           .env("JUST_COMMAND_COLOR")
           .action(ArgAction::Set)
-          .value_parser(PossibleValuesParser::new(arg::COMMAND_COLOR_VALUES))
+          .value_parser(clap::value_parser!(CommandColor))
           .help("Echo recipe lines in <COMMAND-COLOR>"),
       )
-      .arg(Arg::new(arg::YES).long("yes").action(ArgAction::SetTrue).help("Automatically confirm all recipes."))
+      .arg(
+        Arg::new(arg::DOTENV_FILENAME)
+          .long("dotenv-filename")
+          .action(ArgAction::Set)
+          .help("Search for environment file named <DOTENV-FILENAME> instead of `.env`")
+          .conflicts_with(arg::DOTENV_PATH),
+      )
+      .arg(
+        Arg::new(arg::DOTENV_PATH)
+          .short('E')
+          .long("dotenv-path")
+          .action(ArgAction::Set)
+          .value_parser(value_parser!(PathBuf))
+          .help("Load <DOTENV-PATH> as environment file instead of searching for one"),
+      )
       .arg(
         Arg::new(arg::DRY_RUN)
           .short('n')
@@ -203,66 +197,30 @@ impl Config {
       .arg(
         Arg::new(arg::DUMP_FORMAT)
           .long("dump-format")
+          .env("JUST_DUMP_FORMAT")
           .action(ArgAction::Set)
-          .value_parser(PossibleValuesParser::new(arg::DUMP_FORMAT_VALUES))
-          .default_value(arg::DUMP_FORMAT_JUST)
+          .value_parser(clap::value_parser!(DumpFormat))
+          .default_value("just")
           .value_name("FORMAT")
           .help("Dump justfile as <FORMAT>"),
       )
+      .arg(
+        Arg::new(arg::GLOBAL_JUSTFILE)
+          .action(ArgAction::SetTrue)
+          .long("global-justfile")
+          .short('g')
+          .conflicts_with(arg::JUSTFILE)
+          .conflicts_with(arg::WORKING_DIRECTORY)
+          .help("Use global justfile"),
+      )
       .arg(
         Arg::new(arg::HIGHLIGHT)
           .long("highlight")
+          .env("JUST_HIGHLIGHT")
           .action(ArgAction::SetTrue)
           .help("Highlight echoed recipe lines in bold")
           .overrides_with(arg::NO_HIGHLIGHT),
       )
-      .arg(
-        Arg::new(arg::LIST_HEADING)
-          .long("list-heading")
-          .help("Print <TEXT> before list")
-          .value_name("TEXT")
-          .action(ArgAction::Set),
-      )
-      .arg(
-        Arg::new(arg::LIST_PREFIX)
-          .long("list-prefix")
-          .help("Print <TEXT> before each list item")
-          .value_name("TEXT")
-          .action(ArgAction::Set),
-      )
-      .arg(
-        Arg::new(arg::LIST_SUBMODULES)
-          .long("list-submodules")
-          .help("List recipes in submodules")
-          .action(ArgAction::SetTrue)
-          .env("JUST_LIST_SUBMODULES"),
-      )
-      .arg(
-        Arg::new(arg::NO_ALIASES)
-          .long("no-aliases")
-          .action(ArgAction::SetTrue)
-          .help("Don't show aliases in list"),
-      )
-      .arg (
-        Arg::new(arg::NO_DEPS)
-          .long("no-deps")
-          .alias("no-dependencies")
-          .action(ArgAction::SetTrue)
-          .help("Don't run recipe dependencies")
-      )
-      .arg(
-        Arg::new(arg::NO_DOTENV)
-          .long("no-dotenv")
-          .action(ArgAction::SetTrue)
-          .help("Don't load `.env` file"),
-      )
-      .arg(
-        Arg::new(arg::NO_HIGHLIGHT)
-          .long("no-highlight")
-          .action(ArgAction::SetTrue)
-          .help("Don't highlight echoed recipe lines in bold")
-          .overrides_with(arg::HIGHLIGHT),
-      )
       .arg(
         Arg::new(arg::JUSTFILE)
           .short('f')
@@ -272,6 +230,62 @@ impl Config {
           .value_parser(value_parser!(PathBuf))
           .help("Use <JUSTFILE> as justfile"),
       )
+      .arg(
+        Arg::new(arg::LIST_HEADING)
+          .long("list-heading")
+          .env("JUST_LIST_HEADING")
+          .help("Print <TEXT> before list")
+          .value_name("TEXT")
+          .default_value("Available recipes:\n")
+          .action(ArgAction::Set),
+      )
+      .arg(
+        Arg::new(arg::LIST_PREFIX)
+          .long("list-prefix")
+          .env("JUST_LIST_PREFIX")
+          .help("Print <TEXT> before each list item")
+          .value_name("TEXT")
+          .default_value("    ")
+          .action(ArgAction::Set),
+      )
+      .arg(
+        Arg::new(arg::LIST_SUBMODULES)
+          .long("list-submodules")
+          .env("JUST_LIST_SUBMODULES")
+          .help("List recipes in submodules")
+          .action(ArgAction::SetTrue)
+          .env("JUST_LIST_SUBMODULES"),
+      )
+      .arg(
+        Arg::new(arg::NO_ALIASES)
+          .long("no-aliases")
+          .env("JUST_NO_ALIASES")
+          .action(ArgAction::SetTrue)
+          .help("Don't show aliases in list"),
+      )
+      .arg(
+        Arg::new(arg::NO_DEPS)
+          .long("no-deps")
+          .env("JUST_NO_DEPS")
+          .alias("no-dependencies")
+          .action(ArgAction::SetTrue)
+          .help("Don't run recipe dependencies"),
+      )
+      .arg(
+        Arg::new(arg::NO_DOTENV)
+          .long("no-dotenv")
+          .env("JUST_NO_DOTENV")
+          .action(ArgAction::SetTrue)
+          .help("Don't load `.env` file"),
+      )
+      .arg(
+        Arg::new(arg::NO_HIGHLIGHT)
+          .long("no-highlight")
+          .env("JUST_NO_HIGHLIGHT")
+          .action(ArgAction::SetTrue)
+          .help("Don't highlight echoed recipe lines in bold")
+          .overrides_with(arg::HIGHLIGHT),
+      )
       .arg(
         Arg::new(arg::QUIET)
           .short('q')
@@ -311,15 +325,24 @@ impl Config {
           .help("Invoke <COMMAND> with the shell used to run recipe lines and backticks"),
       )
       .arg(
-        Arg::new(arg::CLEAR_SHELL_ARGS)
-          .long("clear-shell-args")
+        Arg::new(arg::TIMESTAMP)
           .action(ArgAction::SetTrue)
-          .overrides_with(arg::SHELL_ARG)
-          .help("Clear shell arguments"),
+          .long("timestamp")
+          .env("JUST_TIMESTAMP")
+          .help("Print recipe command timestamps"),
+      )
+      .arg(
+        Arg::new(arg::TIMESTAMP_FORMAT)
+          .action(ArgAction::Set)
+          .long("timestamp-format")
+          .env("JUST_TIMESTAMP_FORMAT")
+          .default_value("%H:%M:%S")
+          .help("Timestamp format string"),
       )
       .arg(
         Arg::new(arg::UNSORTED)
           .long("unsorted")
+          .env("JUST_UNSORTED")
           .short('u')
           .action(ArgAction::SetTrue)
           .help("Return list and summary entries in source order"),
@@ -350,13 +373,28 @@ impl Config {
           .help("Use <WORKING-DIRECTORY> as working directory. --justfile must also be set")
           .requires(arg::JUSTFILE),
       )
+      .arg(
+        Arg::new(arg::YES)
+          .long("yes")
+          .env("JUST_YES")
+          .action(ArgAction::SetTrue)
+          .help("Automatically confirm all recipes."),
+      )
       .arg(
         Arg::new(cmd::CHANGELOG)
           .long("changelog")
           .action(ArgAction::SetTrue)
           .help("Print changelog"),
       )
-      .arg(Arg::new(cmd::CHOOSE).long("choose").action(ArgAction::SetTrue).help(CHOOSE_HELP))
+      .arg(
+        Arg::new(cmd::CHOOSE)
+          .long("choose")
+          .action(ArgAction::SetTrue)
+          .help(
+            "Select one or more recipes to run using a binary chooser. If `--chooser` is not \
+             passed the chooser defaults to the value of $JUST_CHOOSER, falling back to `fzf`",
+          ),
+      )
       .arg(
         Arg::new(cmd::COMMAND)
           .long("command")
@@ -395,6 +433,7 @@ impl Config {
       .arg(
         Arg::new(cmd::EVALUATE)
           .long("evaluate")
+          .alias("eval")
           .action(ArgAction::SetTrue)
           .help(
             "Evaluate and print all variables. If a variable name is given as an argument, only \
@@ -408,6 +447,12 @@ impl Config {
           .action(ArgAction::SetTrue)
           .help("Format and overwrite justfile"),
       )
+      .arg(
+        Arg::new(cmd::GROUPS)
+          .long("groups")
+          .action(ArgAction::SetTrue)
+          .help("List recipe groups"),
+      )
       .arg(
         Arg::new(cmd::INIT)
           .long("init")
@@ -425,12 +470,6 @@ impl Config {
           .conflicts_with(arg::ARGUMENTS)
           .help("List available recipes"),
       )
-      .arg(
-        Arg::new(cmd::GROUPS)
-        .long("groups")
-        .action(ArgAction::SetTrue)
-        .help("List recipe groups")
-        )
       .arg(
         Arg::new(cmd::MAN)
           .long("man")
@@ -459,21 +498,6 @@ impl Config {
           .action(ArgAction::SetTrue)
           .help("List names of variables"),
       )
-      .arg(
-        Arg::new(arg::DOTENV_FILENAME)
-          .long("dotenv-filename")
-          .action(ArgAction::Set)
-          .help("Search for environment file named <DOTENV-FILENAME> instead of `.env`")
-          .conflicts_with(arg::DOTENV_PATH),
-      )
-      .arg(
-        Arg::new(arg::DOTENV_PATH)
-          .short('E')
-          .long("dotenv-path")
-          .action(ArgAction::Set)
-          .value_parser(value_parser!(PathBuf))
-          .help("Load <DOTENV-PATH> as environment file instead of searching for one")
-      )
       .group(ArgGroup::new("SUBCOMMAND").args(cmd::ALL))
       .arg(
         Arg::new(arg::ARGUMENTS)
@@ -481,83 +505,6 @@ impl Config {
           .action(ArgAction::Append)
           .help("Overrides and recipe(s) to run, defaulting to the first recipe in the justfile"),
       )
-    .arg(
-      Arg::new(arg::GLOBAL_JUSTFILE)
-      .action(ArgAction::SetTrue)
-      .long("global-justfile")
-      .short('g')
-      .conflicts_with(arg::JUSTFILE)
-      .conflicts_with(arg::WORKING_DIRECTORY)
-      .help("Use global justfile")
-    )
-    .arg(
-      Arg::new(arg::TIMESTAMP)
-      .action(ArgAction::SetTrue)
-      .long("timestamp")
-      .env("JUST_TIMESTAMP")
-      .help("Print recipe command timestamps")
-    )
-    .arg(
-      Arg::new(arg::TIMESTAMP_FORMAT)
-      .action(ArgAction::Set)
-      .long("timestamp-format")
-      .env("JUST_TIMESTAMP_FORMAT")
-      .default_value("%H:%M:%S")
-      .help("Timestamp format string")
-    )
-  }
-
-  fn color_from_matches(matches: &ArgMatches) -> ConfigResult<Color> {
-    let value = matches
-      .get_one::<String>(arg::COLOR)
-      .ok_or_else(|| ConfigError::Internal {
-        message: "`--color` had no value".to_string(),
-      })?;
-
-    match value.as_str() {
-      arg::COLOR_AUTO => Ok(Color::auto()),
-      arg::COLOR_ALWAYS => Ok(Color::always()),
-      arg::COLOR_NEVER => Ok(Color::never()),
-      _ => Err(ConfigError::Internal {
-        message: format!("Invalid argument `{value}` to --color."),
-      }),
-    }
-  }
-
-  fn command_color_from_matches(matches: &ArgMatches) -> ConfigResult<Option<ansi_term::Color>> {
-    if let Some(value) = matches.get_one::<String>(arg::COMMAND_COLOR) {
-      match value.as_str() {
-        arg::COMMAND_COLOR_BLACK => Ok(Some(ansi_term::Color::Black)),
-        arg::COMMAND_COLOR_BLUE => Ok(Some(ansi_term::Color::Blue)),
-        arg::COMMAND_COLOR_CYAN => Ok(Some(ansi_term::Color::Cyan)),
-        arg::COMMAND_COLOR_GREEN => Ok(Some(ansi_term::Color::Green)),
-        arg::COMMAND_COLOR_PURPLE => Ok(Some(ansi_term::Color::Purple)),
-        arg::COMMAND_COLOR_RED => Ok(Some(ansi_term::Color::Red)),
-        arg::COMMAND_COLOR_YELLOW => Ok(Some(ansi_term::Color::Yellow)),
-        value => Err(ConfigError::Internal {
-          message: format!("Invalid argument `{value}` to --command-color."),
-        }),
-      }
-    } else {
-      Ok(None)
-    }
-  }
-
-  fn dump_format_from_matches(matches: &ArgMatches) -> ConfigResult<DumpFormat> {
-    let value =
-      matches
-        .get_one::<String>(arg::DUMP_FORMAT)
-        .ok_or_else(|| ConfigError::Internal {
-          message: "`--dump-format` had no value".to_string(),
-        })?;
-
-    match value.as_str() {
-      arg::DUMP_FORMAT_JSON => Ok(DumpFormat::Json),
-      arg::DUMP_FORMAT_JUST => Ok(DumpFormat::Just),
-      _ => Err(ConfigError::Internal {
-        message: format!("Invalid argument `{value}` to --dump-format."),
-      }),
-    }
   }
 
   fn parse_module_path(values: ValuesRef<String>) -> ConfigResult<ModulePath> {
@@ -611,17 +558,6 @@ impl Config {
   }
 
   pub(crate) fn from_matches(matches: &ArgMatches) -> ConfigResult<Self> {
-    let invocation_directory = env::current_dir().context(config_error::CurrentDirContext)?;
-
-    let verbosity = if matches.get_flag(arg::QUIET) {
-      Verbosity::Quiet
-    } else {
-      Verbosity::from_flag_occurrences(matches.get_count(arg::VERBOSE))
-    };
-
-    let color = Self::color_from_matches(matches)?;
-    let command_color = Self::command_color_from_matches(matches)?;
-
     let mut overrides = BTreeMap::new();
     if let Some(mut values) = matches.get_many::<String>(arg::SET) {
       while let (Some(k), Some(v)) = (values.next(), values.next()) {
@@ -684,28 +620,10 @@ impl Config {
       }
     } else if let Some(&shell) = matches.get_one::<completions::Shell>(cmd::COMPLETIONS) {
       Subcommand::Completions { shell }
-    } else if matches.get_flag(cmd::EDIT) {
-      Subcommand::Edit
-    } else if matches.get_flag(cmd::SUMMARY) {
-      Subcommand::Summary
     } else if matches.get_flag(cmd::DUMP) {
       Subcommand::Dump
-    } else if matches.get_flag(cmd::FORMAT) {
-      Subcommand::Format
-    } else if matches.get_flag(cmd::INIT) {
-      Subcommand::Init
-    } else if let Some(path) = matches.get_many::<String>(cmd::LIST) {
-      Subcommand::List {
-        path: Self::parse_module_path(path)?,
-      }
-    } else if matches.get_flag(cmd::GROUPS) {
-      Subcommand::Groups
-    } else if matches.get_flag(cmd::MAN) {
-      Subcommand::Man
-    } else if let Some(path) = matches.get_many::<String>(cmd::SHOW) {
-      Subcommand::Show {
-        path: Self::parse_module_path(path)?,
-      }
+    } else if matches.get_flag(cmd::EDIT) {
+      Subcommand::Edit
     } else if matches.get_flag(cmd::EVALUATE) {
       if positional.arguments.len() > 1 {
         return Err(ConfigError::SubcommandArguments {
@@ -722,6 +640,24 @@ impl Config {
         variable: positional.arguments.into_iter().next(),
         overrides,
       }
+    } else if matches.get_flag(cmd::FORMAT) {
+      Subcommand::Format
+    } else if matches.get_flag(cmd::GROUPS) {
+      Subcommand::Groups
+    } else if matches.get_flag(cmd::INIT) {
+      Subcommand::Init
+    } else if let Some(path) = matches.get_many::<String>(cmd::LIST) {
+      Subcommand::List {
+        path: Self::parse_module_path(path)?,
+      }
+    } else if matches.get_flag(cmd::MAN) {
+      Subcommand::Man
+    } else if let Some(path) = matches.get_many::<String>(cmd::SHOW) {
+      Subcommand::Show {
+        path: Self::parse_module_path(path)?,
+      }
+    } else if matches.get_flag(cmd::SUMMARY) {
+      Subcommand::Summary
     } else if matches.get_flag(cmd::VARIABLES) {
       Subcommand::Variables
     } else {
@@ -731,41 +667,41 @@ impl Config {
       }
     };
 
-    let shell_args = if matches.get_flag(arg::CLEAR_SHELL_ARGS) {
-      Some(Vec::new())
-    } else {
-      matches
-        .get_many::<String>(arg::SHELL_ARG)
-        .map(|s| s.map(Into::into).collect())
-    };
-
-    let unstable = matches.get_flag(arg::UNSTABLE);
+    let unstable = matches.get_flag(arg::UNSTABLE) || subcommand == Subcommand::Summary;
 
     Ok(Self {
       check: matches.get_flag(arg::CHECK),
-      color,
-      command_color,
+      color: (*matches.get_one::<UseColor>(arg::COLOR).unwrap()).into(),
+      command_color: matches
+        .get_one::<CommandColor>(arg::COMMAND_COLOR)
+        .copied()
+        .map(CommandColor::into),
       dotenv_filename: matches
         .get_one::<String>(arg::DOTENV_FILENAME)
         .map(Into::into),
       dotenv_path: matches.get_one::<PathBuf>(arg::DOTENV_PATH).map(Into::into),
       dry_run: matches.get_flag(arg::DRY_RUN),
-      dump_format: Self::dump_format_from_matches(matches)?,
+      dump_format: matches
+        .get_one::<DumpFormat>(arg::DUMP_FORMAT)
+        .unwrap()
+        .clone(),
       highlight: !matches.get_flag(arg::NO_HIGHLIGHT),
-      invocation_directory,
-      list_heading: matches
-        .get_one::<String>(arg::LIST_HEADING)
-        .map_or_else(|| "Available recipes:\n".into(), Into::into),
-      list_prefix: matches
-        .get_one::<String>(arg::LIST_PREFIX)
-        .map_or_else(|| "    ".into(), Into::into),
+      invocation_directory: env::current_dir().context(config_error::CurrentDirContext)?,
+      list_heading: matches.get_one::<String>(arg::LIST_HEADING).unwrap().into(),
+      list_prefix: matches.get_one::<String>(arg::LIST_PREFIX).unwrap().into(),
       list_submodules: matches.get_flag(arg::LIST_SUBMODULES),
       load_dotenv: !matches.get_flag(arg::NO_DOTENV),
       no_aliases: matches.get_flag(arg::NO_ALIASES),
       no_dependencies: matches.get_flag(arg::NO_DEPS),
       search_config,
       shell: matches.get_one::<String>(arg::SHELL).map(Into::into),
-      shell_args,
+      shell_args: if matches.get_flag(arg::CLEAR_SHELL_ARGS) {
+        Some(Vec::new())
+      } else {
+        matches
+          .get_many::<String>(arg::SHELL_ARG)
+          .map(|s| s.map(Into::into).collect())
+      },
       shell_command: matches.get_flag(arg::SHELL_COMMAND),
       subcommand,
       timestamp: matches.get_flag(arg::TIMESTAMP),
@@ -775,12 +711,16 @@ impl Config {
         .into(),
       unsorted: matches.get_flag(arg::UNSORTED),
       unstable,
-      verbosity,
+      verbosity: if matches.get_flag(arg::QUIET) {
+        Verbosity::Quiet
+      } else {
+        Verbosity::from_flag_occurrences(matches.get_count(arg::VERBOSE))
+      },
       yes: matches.get_flag(arg::YES),
     })
   }
 
-  pub(crate) fn require_unstable(&self, message: &str) -> Result<(), Error<'static>> {
+  pub(crate) fn require_unstable(&self, message: &str) -> RunResult<'static> {
     if self.unstable {
       Ok(())
     } else {
@@ -790,7 +730,7 @@ impl Config {
     }
   }
 
-  pub(crate) fn run(self, loader: &Loader) -> Result<(), Error> {
+  pub(crate) fn run(self, loader: &Loader) -> RunResult {
     if let Err(error) = InterruptHandler::install(self.verbosity) {
       warn!("Failed to set CTRL-C handler: {error}");
     }
@@ -821,6 +761,7 @@ mod tests {
       $(shell_args: $shell_args:expr,)?
       $(subcommand: $subcommand:expr,)?
       $(unsorted: $unsorted:expr,)?
+      $(unstable: $unstable:expr,)?
       $(verbosity: $verbosity:expr,)?
     } => {
       #[test]
@@ -841,6 +782,7 @@ mod tests {
           $(shell_args: $shell_args,)?
           $(subcommand: $subcommand,)?
           $(unsorted: $unsorted,)?
+          $(unstable: $unstable,)?
           $(verbosity: $verbosity,)?
           ..testing::config(&[])
         };
@@ -1355,6 +1297,7 @@ mod tests {
     name: subcommand_summary,
     args: ["--summary"],
     subcommand: Subcommand::Summary,
+    unstable: true,
   }
 
   test! {
