@@ -13,33 +13,40 @@
   overlapping_range_endpoints
 )]
 
+//! `just` is primarily used as a command-line binary, but does provide a
+//! limited public library interface.
+//!
+//! Please keep in mind that there are no semantic version guarantees for the
+//! library interface. It may break or change at any time.
+
 pub(crate) use {
   crate::{
     alias::Alias, analyzer::Analyzer, argument_parser::ArgumentParser, assignment::Assignment,
     assignment_resolver::AssignmentResolver, ast::Ast, attribute::Attribute, binding::Binding,
-    color::Color, color_display::ColorDisplay, command_ext::CommandExt, compilation::Compilation,
-    compile_error::CompileError, compile_error_kind::CompileErrorKind, compiler::Compiler,
-    condition::Condition, conditional_operator::ConditionalOperator, config::Config,
-    config_error::ConfigError, constants::constants, count::Count, delimiter::Delimiter,
-    dependency::Dependency, dump_format::DumpFormat, enclosure::Enclosure, error::Error,
-    evaluator::Evaluator, execution_context::ExecutionContext, expression::Expression,
-    fragment::Fragment, function::Function, interrupt_guard::InterruptGuard,
-    interrupt_handler::InterruptHandler, item::Item, justfile::Justfile, keyed::Keyed,
-    keyword::Keyword, lexer::Lexer, line::Line, list::List, load_dotenv::load_dotenv,
-    loader::Loader, module_path::ModulePath, name::Name, namepath::Namepath, ordinal::Ordinal,
-    output::output, output_error::OutputError, parameter::Parameter, parameter_kind::ParameterKind,
-    parser::Parser, platform::Platform, platform_interface::PlatformInterface, position::Position,
-    positional::Positional, ran::Ran, range_ext::RangeExt, recipe::Recipe,
-    recipe_resolver::RecipeResolver, recipe_signature::RecipeSignature, scope::Scope,
-    search::Search, search_config::SearchConfig, search_error::SearchError, set::Set,
-    setting::Setting, settings::Settings, shebang::Shebang, shell::Shell,
-    show_whitespace::ShowWhitespace, source::Source, string_kind::StringKind,
+    color::Color, color_display::ColorDisplay, command_color::CommandColor,
+    command_ext::CommandExt, compilation::Compilation, compile_error::CompileError,
+    compile_error_kind::CompileErrorKind, compiler::Compiler, condition::Condition,
+    conditional_operator::ConditionalOperator, config::Config, config_error::ConfigError,
+    constants::constants, count::Count, delimiter::Delimiter, dependency::Dependency,
+    dump_format::DumpFormat, enclosure::Enclosure, error::Error, evaluator::Evaluator,
+    execution_context::ExecutionContext, expression::Expression, fragment::Fragment,
+    function::Function, interrupt_guard::InterruptGuard, interrupt_handler::InterruptHandler,
+    item::Item, justfile::Justfile, keyed::Keyed, keyword::Keyword, lexer::Lexer, line::Line,
+    list::List, load_dotenv::load_dotenv, loader::Loader, module_path::ModulePath, name::Name,
+    namepath::Namepath, ordinal::Ordinal, output::output, output_error::OutputError,
+    parameter::Parameter, parameter_kind::ParameterKind, parser::Parser, platform::Platform,
+    platform_interface::PlatformInterface, position::Position, positional::Positional, ran::Ran,
+    range_ext::RangeExt, recipe::Recipe, recipe_resolver::RecipeResolver,
+    recipe_signature::RecipeSignature, scope::Scope, search::Search, search_config::SearchConfig,
+    search_error::SearchError, set::Set, setting::Setting, settings::Settings, shebang::Shebang,
+    shell::Shell, show_whitespace::ShowWhitespace, source::Source, string_kind::StringKind,
     string_literal::StringLiteral, subcommand::Subcommand, suggestion::Suggestion, table::Table,
     thunk::Thunk, token::Token, token_kind::TokenKind, unresolved_dependency::UnresolvedDependency,
     unresolved_recipe::UnresolvedRecipe, use_color::UseColor, variables::Variables,
     verbosity::Verbosity, warning::Warning,
   },
   camino::Utf8Path,
+  clap::ValueEnum,
   derivative::Derivative,
   edit_distance::edit_distance,
   lexiclean::Lexiclean,
@@ -86,10 +93,11 @@ pub use crate::run::run;
 #[doc(hidden)]
 pub use unindent::unindent;
 
-pub(crate) type CompileResult<'a, T = ()> = Result<T, CompileError<'a>>;
-pub(crate) type ConfigResult<T> = Result<T, ConfigError>;
-pub(crate) type RunResult<'a, T = ()> = Result<T, Error<'a>>;
-pub(crate) type SearchResult<T> = Result<T, SearchError>;
+type CompileResult<'a, T = ()> = Result<T, CompileError<'a>>;
+type ConfigResult<T> = Result<T, ConfigError>;
+type FunctionResult = Result<String, String>;
+type RunResult<'a, T = ()> = Result<T, Error<'a>>;
+type SearchResult<T> = Result<T, SearchError>;
 
 #[cfg(test)]
 #[macro_use]
@@ -121,6 +129,7 @@ mod attribute;
 mod binding;
 mod color;
 mod color_display;
+mod command_color;
 mod command_ext;
 mod compilation;
 mod compile_error;
