@@ -365,12 +365,15 @@ impl<'run, 'src> Parser<'run, 'src> {
             });
           }
           Some(Keyword::Mod)
-            if self.next_are(&[Identifier, Identifier, StringToken])
-              || self.next_are(&[Identifier, Identifier, Identifier, StringToken])
+            if self.next_are(&[Identifier, Identifier, Comment])
               || self.next_are(&[Identifier, Identifier, Eof])
               || self.next_are(&[Identifier, Identifier, Eol])
+              || self.next_are(&[Identifier, Identifier, Identifier, StringToken])
+              || self.next_are(&[Identifier, Identifier, StringToken])
               || self.next_are(&[Identifier, QuestionMark]) =>
           {
+            let doc = pop_doc_comment(&mut items, eol_since_last_comment);
+
             self.presume_keyword(Keyword::Mod)?;
 
             let optional = self.accepted(QuestionMark)?;
@@ -386,6 +389,7 @@ impl<'run, 'src> Parser<'run, 'src> {
 
             items.push(Item::Module {
               absolute: None,
+              doc,
               name,
               optional,
               relative,
@@ -2564,7 +2568,7 @@ mod tests {
     kind: FunctionArgumentCountMismatch {
       function: "arch",
       found: 1,
-      expected: 0..0,
+      expected: 0..=0,
     },
   }
 
@@ -2578,7 +2582,7 @@ mod tests {
     kind: FunctionArgumentCountMismatch {
       function: "env_var",
       found: 0,
-      expected: 1..1,
+      expected: 1..=1,
     },
   }
 
@@ -2592,7 +2596,7 @@ mod tests {
     kind: FunctionArgumentCountMismatch {
       function: "env",
       found: 3,
-      expected: 1..2,
+      expected: 1..=2,
     },
   }
 
@@ -2606,7 +2610,7 @@ mod tests {
     kind: FunctionArgumentCountMismatch {
       function: "env",
       found: 0,
-      expected: 1..2,
+      expected: 1..=2,
     },
   }
 
@@ -2620,7 +2624,7 @@ mod tests {
     kind: FunctionArgumentCountMismatch {
       function: "env_var_or_default",
       found: 1,
-      expected: 2..2,
+      expected: 2..=2,
     },
   }
 
@@ -2634,7 +2638,7 @@ mod tests {
     kind: FunctionArgumentCountMismatch {
       function: "join",
       found: 1,
-      expected: 2..usize::MAX,
+      expected: 2..=usize::MAX,
     },
   }
 
@@ -2648,7 +2652,7 @@ mod tests {
     kind: FunctionArgumentCountMismatch {
       function: "replace",
       found: 1,
-      expected: 3..3,
+      expected: 3..=3,
     },
   }
 }
